@@ -1,4 +1,8 @@
-from collections import Counter, OrderedDict, Mapping, namedtuple
+from collections import Counter, OrderedDict
+try:
+    from collections.abc import Mapping
+except ImportError:  # python <3.7
+    from collections import Mapping
 from decimal import Decimal
 import datetime
 import logging
@@ -20,9 +24,6 @@ import django.conf
 
 from qary import __version__
 
-# tuple to hold score, text, and bot-name
-BotReply = namedtuple('BotReply', ['confidence', 'text', 'skill'], defaults=[None] * 3)  # noqa
-
 # TODO: Do Django ACCESS_KEY and SECRET need to be integrated into env ?
 env = Environment(spacy_lang=str, loglevel=int, name=str)
 # if you need consistent hashes from builtin hash function set env['PYTHONHASHSEED']
@@ -33,11 +34,10 @@ BASE_DIR = os.path.dirname(SRC_DIR)
 DATA_DIR = os.path.join(SRC_DIR, 'data')
 LOG_DIR = os.path.join(DATA_DIR, 'log')
 CONSTANTS_DIR = os.path.join(DATA_DIR, 'constants')
-HISTORY_PATH = os.path.join(DATA_DIR, 'history.json')
+HISTORY_PATH = os.path.join(DATA_DIR, 'history.yml')
 os.makedirs(LOG_DIR, exist_ok=True)
 os.makedirs(CONSTANTS_DIR, exist_ok=True)
-# with open(HISTORY_PATH, 'a') as fap:
-#     pass
+
 MIDATA_DOMAINNAME = 'tan.sfo2.digitaloceanspaces.com'
 MIDATA_URL = f'https://{MIDATA_DOMAINNAME}'
 MIDATA_QA_MODEL_DIR = 'midata/public/models/qa'
@@ -46,6 +46,7 @@ ARTICLES_URL = f'{MIDATA_URL}/midata/public/corpora/wikipedia/articles_with_keyw
 
 USE_CUDA = False
 MAX_TURNS = 10000
+DEFAULT_SKILL_CONFIDENCE = .667
 
 
 DEFAULT_CONFIG = {
