@@ -13,7 +13,10 @@ FIXME: Use builtin pathlib.Path and URL classes
 >>> basename('http://www.example.com/basename.some.big.tar.gz')
 'basename'
 """
-from collections import Mapping
+try:
+    from collections.abc import Mapping
+except ImportError:  # python <3.7
+    from collections import Mapping
 from configparser import ConfigParser
 import datetime
 import errno
