@@ -4,7 +4,8 @@ import random
 import re
 # from collections import namedtuple
 
-from qary.constants import DATA_DIR, BotReply
+from qary.constants import DATA_DIR
+from qary.skills.base import BotReply
 
 # python 2/3 compatibility
 try:
