@@ -5,6 +5,7 @@ import logging
 
 from qary.etl import faqs
 from qary.constants import FAQ_DOMAINS, FAQ_MIN_SIMILARITY, FAQ_MAX_NUM_REPLIES
+from qary.skills.base import BotReply
 from qary import spacy_language_model
 from qary.etl import knowledge_extraction as extract  # noqa
 import numpy as np
@@ -25,7 +26,7 @@ class Skill:
     r""" Skill that can reply with answers to frequently asked questions using data/faq/*.yml
 
     >>> bot = Skill()
-    >>> bot.reply('What are the basic variable data types in python?')[0][-1]
+    >>> bot.reply('What are the basic variable data types in python?')[0][1]
     '`float`, `int`, `str`, and `bool`'
     """
 
@@ -45,10 +46,12 @@ class Skill:
         question_similarities = self.faq['question_vectors'].dot(question_vector.reshape(-1, 1))
         idx = question_similarities.argmax()
         mask = np.array(question_similarities).flatten() >= FAQ_MIN_SIMILARITY
+        # TODO: progressively expand threshold in case there are many more than FAQ_MAX_NUM_REPLIES similar Q's
         if sum(mask) >= 1:
-            responses.extend(list(zip(question_similarities[mask],
-                                      (str(a) for a in self.faq['answers'][mask])
-                                      )))
+            responses.extend(BotReply(confidence, text) for confidence, text in
+                             zip(question_similarities[mask],
+                                 (str(a) for a in self.faq['answers'][mask])
+                                 ))
             responses = sorted(responses, reverse=True)[:FAQ_MAX_NUM_REPLIES]
         else:
             responses = [(
