@@ -7,7 +7,7 @@ from qary.etl import glossaries
 from qary import spacy_language_model
 from qary.etl import knowledge_extraction as extract
 from qary.skills.base import ContextBot
-from qary.constants import BotReply
+from qary.skills.base import BotReply
 
 log = logging.getLogger(__name__)
 nlp = spacy_language_model.load('en_core_web_md')
