@@ -10,10 +10,11 @@ import numpy as np
 from multiprocessing import cpu_count
 
 from qary.qa.torch_models import QuestionAnsweringModel
-from qary.constants import DATA_DIR, USE_CUDA, MIDATA_URL, MIDATA_QA_MODEL_DIR, BotReply, args
+from qary.constants import DATA_DIR, USE_CUDA, MIDATA_URL, MIDATA_QA_MODEL_DIR, args
+from qary.skills.base import BotReply
 from qary.skills.base import ContextBot
 from qary.etl.netutils import DownloadProgressBar
-from qary.etl import scrape_wikipedia
+from qary.etl import wikipedia_api
 
 log = logging.getLogger(__name__)
 
@@ -38,7 +39,7 @@ class Skill(ContextBot):
         log.debug(f"Attempting to download url: {url_str}")
         model_dir = os.path.join(DATA_DIR, 'qa-models', f"{qa_model}")
         model_type = qa_model.split('-')[0].lower()
-        self.wikiscraper = scrape_wikipedia.WikiScraper()
+        self.wikiscraper = wikipedia_api.WikiScraper()
         if not os.path.isdir(model_dir):
             os.makedirs(model_dir)
 
@@ -136,7 +137,7 @@ class Skill(ContextBot):
         docs = self.context.get('docs') or [self.context['doc']['text']]
         for i, text in enumerate(docs):
             log.info(
-                f"text[{i}] from context['doc']['text'] or scrape_wikipedia: "
+                f"text[{i}] from context['doc']['text'] or wikipedia_api: "
                 f"{repr(text)[:40]}...{repr(text)[-40:]} ({len(text)} chars)")
             super().update_context(context=dict(doc=dict(text=text)))
             if len(text.strip()) < 2:
